#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-cairo-connector
version:              0.1.1
visibility:           public
id:                   gi-cairo-connector-0.1.1-GkK2rGeS5z73Vc9WU4lQnd
key:                  gi-cairo-connector-0.1.1-GkK2rGeS5z73Vc9WU4lQnd
license:              LGPL-2.1-only
copyright:            (c) 2018 Kilian Kilger, Iñaki García Etxebarria
maintainer:           Kilian Kilger (kkilger@gmail.com)
author:
    Iñaki García Etxebarria,
    Kilian Kilger

stability:            experimental
homepage:             https://github.com/cohomology/gi-cairo-render
synopsis:             GI friendly Binding to the Cairo library.
description:
    This library contains glue code used to interconnect Haskell GI and Cairo

category:             Graphics
abi:                  18b01a2847ba7c529cae2e276fee594c
exposed:              True
exposed-modules:      GI.Cairo.Render.Connector
import-dirs:          /usr/lib/ghc-9.6.6/site-local/gi-cairo-connector-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gi-cairo-connector-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gi-cairo-connector-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-cairo-connector
hs-libraries:         HSgi-cairo-connector-0.1.1-GkK2rGeS5z73Vc9WU4lQnd
depends:
    base-4.18.2.1 gi-cairo-1.0.30-CngNqgJmOq5ElHlg9ZWjKn
    gi-cairo-render-0.1.2-2RE0dTa0lmd3SA0hreLAyc
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC mtl-2.3.1

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-connector/html/gi-cairo-connector.haddock

haddock-html:         /usr/share/doc/haskell-gi-cairo-connector/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

